==> blesta-5.10.2.zip: blesta/plugins/system_overview/language/zh_cn/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2024, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.canceled'] = '已取消';
$lang['AdminMain.graph_line_name.active'] = '活跃';
$lang['AdminMain.graph_name.graph_clients'] = '客户';
$lang['AdminMain.graph_line_name.new'] = '新';
$lang['AdminMain.graph_line_name.suspended'] = '暂停';
$lang['AdminMain.graph_name.graph_services'] = '服务';
$lang['AdminMain.settings.submit_settings'] = '更新设置';
$lang['AdminMain.settings.submit_cancel'] = '返回概览';
$lang['AdminMain.settings.date_range'] = '图表日期范围';
$lang['AdminMain.settings.show_legend'] = '显示图例';
$lang['AdminMain.settings.tooltip_show_one_tab'] = '不再在标签页中分隔图形，而是在一个标签页中显示所有图形。';
$lang['AdminMain.settings.show_one_tab'] = '只显示一个选项卡';
$lang['AdminMain.settings.heading_settings'] = '设置';
$lang['AdminMain.settings.graph_services'] = '服务图';
$lang['AdminMain.settings.text_graphs_services'] = '检查哪些图表应显示在 "服务 "选项卡上。';
$lang['AdminMain.settings.heading_services'] = '服务选项卡';
$lang['AdminMain.settings.graph_clients'] = '客户图表';
$lang['AdminMain.settings.text_graphs_clients'] = '检查哪些图表应显示在客户选项卡上。';
$lang['AdminMain.settings.heading_clients'] = '客户选项卡';
$lang['AdminMain.settings.pending_orders'] = '待处理订单';
$lang['AdminMain.settings.open_tickets'] = '开放式门票';
$lang['AdminMain.settings.recurring_invoices'] = '经常性发票';
$lang['AdminMain.settings.active_users_today'] = '今日活跃用户';
$lang['AdminMain.settings.services_scheduled_cancellation'] = '计划取消的服务';
$lang['AdminMain.settings.services_active'] = '主动服务';
$lang['AdminMain.settings.clients_active'] = '活跃客户';
$lang['AdminMain.settings.text_options'] = '选中将显示在系统概述上的选项。';
$lang['AdminMain.settings.heading_statistics'] = '统计资料';
$lang['AdminMain.date_range.days'] = '%1$s 天';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s 分钟前';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 分钟前';
$lang['AdminMain.overview.tooltip_last_activity_now'] = '就是现在';
$lang['AdminMain.overview.tooltip_location'] = '地点';
$lang['AdminMain.overview.tooltip_activity'] = '最近活动';
$lang['AdminMain.overview.tab_services'] = '服务';
$lang['AdminMain.overview.tab_clients'] = '客户';
$lang['AdminMain.overview.tab_all'] = '图表';
$lang['AdminMain.overview.heading_users'] = '最近的用户';
$lang['AdminMain.overview.statistic.open_tickets'] = '开放式门票';
$lang['AdminMain.overview.statistic.pending_orders'] = '待处理订单';
$lang['AdminMain.overview.statistic.recurring_invoices'] = '经常性发票';
$lang['AdminMain.overview.statistic.active_users_today'] = '今日活跃用户';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = '计划取消的服务';
$lang['AdminMain.overview.statistic.services_active'] = '主动服务';
$lang['AdminMain.overview.statistic.clients_active'] = '活跃客户';
$lang['AdminMain.index.boxtitle_overview'] = '系统概述';
$lang['AdminMain.!success.options_updated'] = '系统概述设置已成功更新！';

==> blesta-5.11.4.zip: blesta/plugins/system_overview/language/zh_cn/admin_main.php <==
<?php
/**
 * Admin Main
 *
 * @package blesta
 * @subpackage blesta.language.zh_cn
 * @copyright Copyright (c) 2025, Phillips Data, Inc.
 * @license http://www.blesta.com/license/ The Blesta License Agreement
 * @link http://www.blesta.com/ Blesta
 */

$lang['AdminMain.graph_line_name.canceled'] = '已取消';
$lang['AdminMain.graph_line_name.active'] = '活跃';
$lang['AdminMain.graph_name.graph_clients'] = '客户';
$lang['AdminMain.graph_line_name.new'] = '新';
$lang['AdminMain.graph_line_name.suspended'] = '暂停';
$lang['AdminMain.graph_name.graph_services'] = '服务';
$lang['AdminMain.settings.submit_settings'] = '更新设置';
$lang['AdminMain.settings.submit_cancel'] = '返回概览';
$lang['AdminMain.settings.date_range'] = '图表日期范围';
$lang['AdminMain.settings.show_legend'] = '显示图例';
$lang['AdminMain.settings.tooltip_show_one_tab'] = '不再在标签页中分隔图形，而是在一个标签页中显示所有图形。';
$lang['AdminMain.settings.show_one_tab'] = '只显示一个选项卡';
$lang['AdminMain.settings.heading_settings'] = '设置';
$lang['AdminMain.settings.graph_services'] = '服务图';
$lang['AdminMain.settings.text_graphs_services'] = '检查哪些图表应显示在 "服务 "选项卡上。';
$lang['AdminMain.settings.heading_services'] = '服务选项卡';
$lang['AdminMain.settings.graph_clients'] = '客户图表';
$lang['AdminMain.settings.text_graphs_clients'] = '检查哪些图表应显示在客户选项卡上。';
$lang['AdminMain.settings.heading_clients'] = '客户选项卡';
$lang['AdminMain.settings.pending_orders'] = '待处理订单';
$lang['AdminMain.settings.open_tickets'] = '开放式门票';
$lang['AdminMain.settings.recurring_invoices'] = '经常性发票';
$lang['AdminMain.settings.active_users_today'] = '今日活跃用户';
$lang['AdminMain.settings.services_scheduled_cancellation'] = '计划取消的服务';
$lang['AdminMain.settings.services_active'] = '主动服务';
$lang['AdminMain.settings.clients_active'] = '活跃客户';
$lang['AdminMain.settings.text_options'] = '选中将显示在系统概述上的选项。';
$lang['AdminMain.settings.heading_statistics'] = '统计资料';
$lang['AdminMain.date_range.days'] = '%1$s 天';
$lang['AdminMain.overview.tooltip_last_activity_minutes'] = '%1$s 分钟前';
$lang['AdminMain.overview.tooltip_last_activity_minute'] = '1 分钟前';
$lang['AdminMain.overview.tooltip_last_activity_now'] = '就是现在';
$lang['AdminMain.overview.tooltip_location'] = '地点';
$lang['AdminMain.overview.tooltip_activity'] = '最近活动';
$lang['AdminMain.overview.tab_services'] = '服务';
$lang['AdminMain.overview.tab_clients'] = '客户';
$lang['AdminMain.overview.tab_all'] = '图表';
$lang['AdminMain.overview.heading_users'] = '最近的用户';
$lang['AdminMain.overview.statistic.open_tickets'] = '开放式门票';
$lang['AdminMain.overview.statistic.pending_orders'] = '待处理订单';
$lang['AdminMain.overview.statistic.recurring_invoices'] = '经常性发票';
$lang['AdminMain.overview.statistic.active_users_today'] = '今日活跃用户';
$lang['AdminMain.overview.statistic.services_scheduled_cancellation'] = '计划取消的服务';
$lang['AdminMain.overview.statistic.services_active'] = '主动服务';
$lang['AdminMain.overview.statistic.clients_active'] = '活跃客户';
$lang['AdminMain.index.boxtitle_overview'] = '系统概述';
$lang['AdminMain.!success.options_updated'] = '系统概述设置已成功更新！';
$lang['AdminMain.date_range.day'] = '1 天';
$lang['AdminMain.date_range.month'] = '本月';
$lang['AdminMain.date_range.ytd'] = '年度至今';
